@@ -86,6 +86,7 @@ update_icon (NMNetworkMenuItem *item, NMApplet *applet)
 	NMNetworkMenuItemPrivate *priv = NM_NETWORK_MENU_ITEM_GET_PRIVATE (item);
 	gs_unref_object GdkPixbuf *icon_free = NULL, *icon_free2 = NULL;
 	GdkPixbuf *icon;
+	int icon_size, scale;
 	const char *icon_name = NULL;
 
 	if (priv->is_adhoc)
@@ -93,6 +94,13 @@ update_icon (NMNetworkMenuItem *item, NMApplet *applet)
 	else
 		icon_name = mobile_helper_get_quality_icon_name (priv->int_strength);
 
+	scale = gtk_widget_get_scale_factor (GTK_WIDGET (item));
+	icon_size = 24;
+	if (INDICATOR_ENABLED (applet)) {
+		/* Since app_indicator relies on GdkPixbuf, we should not scale it */
+	} else
+		icon_size *= scale;
+
 	icon = nma_icon_check_and_load (icon_name, applet);
 	if (icon) {
 		if (priv->is_encrypted) {
@@ -110,11 +118,20 @@ update_icon (NMNetworkMenuItem *item, NMApplet *applet)
 		}
 
 		/* Scale to menu size if larger so the menu doesn't look awful */
-		if (gdk_pixbuf_get_height (icon) > 24 || gdk_pixbuf_get_width (icon) > 24)
-			icon = icon_free2 = gdk_pixbuf_scale_simple (icon, 24, 24, GDK_INTERP_BILINEAR);
+		if (gdk_pixbuf_get_height (icon) > icon_size || gdk_pixbuf_get_width (icon) > icon_size)
+			icon = icon_free2 = gdk_pixbuf_scale_simple (icon, icon_size, icon_size, GDK_INTERP_BILINEAR);
 	}
 
-	gtk_image_set_from_pixbuf (GTK_IMAGE (priv->strength), icon);
+	if (INDICATOR_ENABLED (applet)) {
+		/* app_indicator only uses GdkPixbuf */
+		gtk_image_set_from_pixbuf (GTK_IMAGE (priv->strength), icon);
+	} else {
+		cairo_surface_t *surface;
+
+		surface = gdk_cairo_surface_create_from_pixbuf (icon, scale, NULL);
+		gtk_image_set_from_surface (GTK_IMAGE (priv->strength), surface);
+		cairo_surface_destroy (surface);
+	}
 }
 
 void
