@@ -7,7 +7,6 @@
  */
 
 #include "nm-default.h"
-#include "nma-private.h"
 
 #include <ctype.h>
 #include <string.h>
@@ -71,7 +70,7 @@ validate (EAPMethod *parent, GError **error)
 	gboolean ret = TRUE;
 
 	if (method->username_requested) {
-		text = gtk_editable_get_text (GTK_EDITABLE (method->username_entry));
+		text = gtk_entry_get_text (method->username_entry);
 		if (!text || !strlen (text)) {
 			widget_set_error (GTK_WIDGET (method->username_entry));
 			g_set_error_literal (error, NMA_ERROR, NMA_ERROR_GENERIC, _("missing EAP username"));
@@ -85,7 +84,7 @@ validate (EAPMethod *parent, GError **error)
 		if (always_ask_selected (method->password_entry))
 			widget_unset_error (GTK_WIDGET (method->password_entry));
 		else {
-			text = gtk_editable_get_text (GTK_EDITABLE (method->password_entry));
+			text = gtk_entry_get_text (method->password_entry);
 			if (!text || !strlen (text)) {
 				widget_set_error (GTK_WIDGET (method->password_entry));
 				if (ret) {
@@ -99,7 +98,7 @@ validate (EAPMethod *parent, GError **error)
 	}
 
 	if (method->pkey_passphrase_requested) {
-		text = gtk_editable_get_text (GTK_EDITABLE (method->pkey_passphrase_entry));
+		text = gtk_entry_get_text (method->pkey_passphrase_entry);
 		if (!text || !strlen (text)) {
 			widget_set_error (GTK_WIDGET (method->pkey_passphrase_entry));
 			if (ret) {
@@ -194,11 +193,8 @@ fill_connection (EAPMethod *parent, NMConnection *connection)
 			nm_setting_802_1x_add_eap_method (s_8021x, eap_type->name);
 	}
 
-	if (method->username_requested) {
-		g_object_set (s_8021x, NM_SETTING_802_1X_IDENTITY,
-		              gtk_editable_get_text (GTK_EDITABLE (method->username_entry)),
-		              NULL);
-	}
+	if (method->username_requested)
+		g_object_set (s_8021x, NM_SETTING_802_1X_IDENTITY, gtk_entry_get_text (method->username_entry), NULL);
 
 	if (method->password_requested) {
 		/* Save the password always ask setting */
@@ -213,8 +209,7 @@ fill_connection (EAPMethod *parent, NMConnection *connection)
 		 */
 		if (!(method->flags & EAP_METHOD_SIMPLE_FLAG_IS_EDITOR) || not_saved == FALSE) {
 			g_object_set (s_8021x, NM_SETTING_802_1X_PASSWORD,
-			              gtk_editable_get_text (GTK_EDITABLE (method->password_entry)),
-			              NULL);
+			              gtk_entry_get_text (method->password_entry), NULL);
 		}
 
 		/* Update secret flags and popup when editing the connection */
@@ -230,8 +225,7 @@ fill_connection (EAPMethod *parent, NMConnection *connection)
 
 	if (method->pkey_passphrase_requested) {
 		g_object_set (s_8021x, NM_SETTING_802_1X_PRIVATE_KEY_PASSWORD,
-		              gtk_editable_get_text (GTK_EDITABLE (method->pkey_passphrase_entry)),
-		              NULL);
+		              gtk_entry_get_text (method->pkey_passphrase_entry), NULL);
 	}
 }
 
@@ -286,19 +280,15 @@ password_storage_changed (GObject *entry,
 static void
 set_userpass_ui (EAPMethodSimple *method)
 {
-	if (method->ws_parent->username) {
-		gtk_editable_set_text (GTK_EDITABLE (method->username_entry),
-		                       method->ws_parent->username);
-	} else {
-		gtk_editable_set_text (GTK_EDITABLE (method->username_entry), "");
-	}
+	if (method->ws_parent->username)
+		gtk_entry_set_text (method->username_entry, method->ws_parent->username);
+	else
+		gtk_entry_set_text (method->username_entry, "");
 
-	if (method->ws_parent->password && !method->ws_parent->always_ask) {
-		gtk_editable_set_text (GTK_EDITABLE (method->password_entry),
-		                                     method->ws_parent->password);
-	} else {
-		gtk_editable_set_text (GTK_EDITABLE (method->password_entry), "");
-	}
+	if (method->ws_parent->password && !method->ws_parent->always_ask)
+		gtk_entry_set_text (method->password_entry, method->ws_parent->password);
+	else
+		gtk_entry_set_text (method->password_entry, "");
 
 	gtk_toggle_button_set_active (method->show_password, method->ws_parent->show_password);
 	password_storage_changed (NULL, NULL, method);
@@ -314,8 +304,8 @@ static void
 widgets_unrealized (GtkWidget *widget, EAPMethodSimple *method)
 {
 	wireless_security_set_userpass (method->ws_parent,
-	                                gtk_editable_get_text (GTK_EDITABLE (method->username_entry)),
-	                                gtk_editable_get_text (GTK_EDITABLE (method->password_entry)),
+	                                gtk_entry_get_text (method->username_entry),
+	                                gtk_entry_get_text (method->password_entry),
 	                                always_ask_selected (method->password_entry),
 	                                gtk_toggle_button_get_active (method->show_password));
 }
