@@ -7,7 +7,6 @@
  */
 
 #include "nm-default.h"
-#include "nma-private.h"
 
 #include <ctype.h>
 #include <string.h>
@@ -52,7 +51,7 @@ validate (WirelessSecurity *parent, GError **error)
 	g_assert (entry);
 
 	secret_flags = nma_utils_menu_to_secret_flags (entry);
-	key = gtk_editable_get_text (GTK_EDITABLE (entry));
+	key = gtk_entry_get_text (GTK_ENTRY (entry));
 	len = key ? strlen (key) : 0;
 
         if (   secret_flags & NM_SETTING_SECRET_FLAG_NOT_SAVED
@@ -116,7 +115,7 @@ fill_connection (WirelessSecurity *parent, NMConnection *connection)
 
 	widget = GTK_WIDGET (gtk_builder_get_object (parent->builder, "wpa_psk_entry"));
 	passwd_entry = widget;
-	key = gtk_editable_get_text (GTK_EDITABLE (widget));
+	key = gtk_entry_get_text (GTK_ENTRY (widget));
 	g_object_set (s_wireless_sec, NM_SETTING_WIRELESS_SECURITY_PSK, key, NULL);
 
 	/* Save PSK_FLAGS to the connection */
@@ -185,7 +184,7 @@ ws_wpa_psk_new (NMConnection *connection, gboolean secrets_only)
 	g_signal_connect (G_OBJECT (widget), "changed",
 	                  (GCallback) wireless_security_changed_cb,
 	                  sec);
-	gtk_editable_set_width_chars (GTK_EDITABLE (widget), 28);
+	gtk_entry_set_width_chars (GTK_ENTRY (widget), 28);
 
 	/* Create password-storage popup menu for password entry under entry's secondary icon */
 	if (connection)
